@@ -18,8 +18,10 @@
 
 #include <qpainter.h>
 #include <qpixmap.h>
-#include <kpixmap.h>
-#include <kpixmapeffect.h>
+//Added by qt3to4:
+#include <QMouseEvent>
+#include <QFrame>
+#include <QResizeEvent>
 
 #include <kstandarddirs.h>
 #include <klocale.h>
@@ -27,16 +29,15 @@
 
 using namespace KBugBusterMainWindow;
 
-CWLoadingWidget::CWLoadingWidget( WidgetMode mode, QWidget *parent,
-                                  const char * name )
-: QFrame( parent, name )
+CWLoadingWidget::CWLoadingWidget( WidgetMode mode, QWidget *parent)
+: QFrame( parent )
 {
     init( mode );
 }
 
 CWLoadingWidget::CWLoadingWidget( const QString &text, WidgetMode mode,
-                                  QWidget *parent, const char * name )
-: QFrame( parent, name )
+                                  QWidget *parent )
+: QFrame( parent)
 {
     init( mode );
     setText( text );
@@ -47,11 +48,11 @@ void CWLoadingWidget::init( WidgetMode mode )
     m_mode = mode;
 
     QPalette pal = palette();
-    pal.setColor( QPalette::Active,   QColorGroup::Background,
+    pal.setColor( QPalette::Active,   QPalette::Background,
                   QColor( 49, 121, 173 ) );
-    pal.setColor( QPalette::Inactive, QColorGroup::Background,
+    pal.setColor( QPalette::Inactive, QPalette::Background,
                   QColor( 49, 121, 173 ) );
-    pal.setColor( QPalette::Disabled, QColorGroup::Background,
+    pal.setColor( QPalette::Disabled, QPalette::Background,
                   QColor( 49, 121, 173 ) );
     setPalette( pal );
 
@@ -59,35 +60,40 @@ void CWLoadingWidget::init( WidgetMode mode )
     setFrameShadow( Sunken );
     setLineWidth( 2 );
 
-    setBackgroundMode( NoBackground ); // no flicker
+    setAttribute(Qt::WA_NoSystemBackground, true);
 
     // Load images and prepare pixmap effect
     if( m_mode == TopFrame )
     {
         m_logoPixmap =
-                new QPixmap( locate( "data", "kbugbuster/pics/logo.png" ) );
+                new QPixmap( KStandardDirs::locate( "data", "kbugbuster/pics/logo.png" ) );
         m_topRightPixmap =
-                new QPixmap( locate( "data", "kbugbuster/pics/top-right.png" ) );
+                new QPixmap( KStandardDirs::locate( "data", "kbugbuster/pics/top-right.png" ) );
         m_barsPixmap =
-                new QPixmap( locate( "data", "kbugbuster/pics/bars.png" ) );
+                new QPixmap( KStandardDirs::locate( "data", "kbugbuster/pics/bars.png" ) );
         m_toolsPixmap = 0L;
         m_toolsPixmapEffect = 0L;
     }
     else
     {
         m_toolsPixmap =
-                new QPixmap( locate( "data", "kbugbuster/pics/tools.png" ) );
+                new QPixmap( KStandardDirs::locate( "data", "kbugbuster/pics/tools.png" ) );
 
-        m_toolsPixmapEffect = new KPixmap( m_toolsPixmap->size() );
+        m_toolsPixmapEffect = new QPixmap( m_toolsPixmap->size() );
 
         QPainter pb;
         pb.begin( m_toolsPixmapEffect );
         pb.fillRect( 0, 0, m_toolsPixmap->width(), m_toolsPixmap->height(),
 		     QBrush(  QColor(  49,  121,  172 ) ) );
         pb.drawPixmap( 0, 0, *m_toolsPixmap );
+        // ### - This might be the right replacement for KPE::fade()?
+        //pb.setCompositionMode(QPainter::CompositionMode_SourceOver);
+        //pb.fillRect( 0, 0, m_toolsPixmap->width(), m_toolsPixmap->height(),
+        //             QBrush(  QColor( 255, 255, 255, 64 ) ) );
         pb.end();
 
-        KPixmapEffect::fade( *m_toolsPixmapEffect, 0.75, white );
+        // FIXME - kdefx is deprecated, use QPainter
+        //KPixmapEffect::fade( *m_toolsPixmapEffect, 0.75, Qt::red );
 
         m_logoPixmap = 0L;
         m_topRightPixmap = 0L;
@@ -115,7 +121,7 @@ void CWLoadingWidget::updatePixmap()
     QRect cr = contentsRect();
     cr.setWidth( cr.width() + 2 );
     cr.setHeight( cr.height() + 2 );
-    m_buffer->resize( cr.width(), cr.height() );
+    *m_buffer = QPixmap( cr.width(), cr.height() );
 
     QPainter p( m_buffer );
 
@@ -141,25 +147,25 @@ void CWLoadingWidget::updatePixmap()
         p.drawPixmap( 0, 0, *m_logoPixmap );
 
         // Draw title text
-        p.setPen( black );
+        p.setPen( Qt::black );
         p.drawText( 150, 84, cr.width() - 150, 108 - 84,
-                    AlignAuto | AlignVCenter, m_text );
+                    Qt::AlignLeft | Qt::AlignVCenter, m_text );
 
         // Draw intro text
         QString desc = i18n( "Welcome to KBugBuster, a tool to manage the "
                              "KDE Bug Report System. With KBugBuster you can "
                              "manage outstanding bug reports for KDE from a "
                              "convenient front end." );
-        p.setPen( black );
+        p.setPen( Qt::black );
         p.drawText( 28, 128, cr.width() - 28, 184 - 128,
-                    AlignAuto | AlignVCenter | WordBreak, desc );
+                    Qt::AlignLeft | Qt::AlignVCenter | Qt::TextWordWrap, desc );
 
         // Draw the caption text
         QString caption = i18n( "KBugBuster" );
         p.setFont( bigFont );
         p.setPen( QColor(139, 183, 222) );
         p.drawText( 220, 60, caption );
-        p.setPen( black );
+        p.setPen( Qt::black );
         p.drawText( 217, 57, caption );
     }
     else
@@ -191,15 +197,15 @@ void CWLoadingWidget::updatePixmap()
 
         QRect br = fontMetrics().boundingRect( boxX, boxY,
                    boxW, cr.height() - boxY - 10 - 2 * fheight,
-                   AlignAuto | AlignTop | WordBreak, m_text );
+                   Qt::AlignLeft | Qt::AlignTop | Qt::TextWordWrap, m_text );
 
         QRect box = br;
         box.setHeight( box.height() + 2 * fheight );
         box.setWidth( box.width() + 2 * 10 );
         if( box.width() < cr.width() - 2 * boxX )
-            box.setWidth( QMIN( cr.width() - 2 * boxX, 500 + 2 * 10 ) );
+            box.setWidth( qMin( cr.width() - 2 * boxX, 500 + 2 * 10 ) );
         if( box.height() < 100 )
-            box.setHeight( QMIN( cr.height() - boxY - 2 * fheight - 10, 100 ) );
+            box.setHeight( qMin( cr.height() - boxY - 2 * fheight - 10, 100 ) );
 
         p.setClipRect( box );
         p.fillRect( box, QBrush( QColor( 204, 222, 234 ) ) );
@@ -209,24 +215,18 @@ void CWLoadingWidget::updatePixmap()
         p.setWindow( 0, 0, box.width(), box.height() );
 
         p.drawText( 10, fheight, br.width(),
-                    QMAX( br.height(), box.height() - 2 * fheight ),
-                    AlignAuto | AlignVCenter | WordBreak, m_text );
+                    qMax( br.height(), box.height() - 2 * fheight ),
+                    Qt::AlignLeft | Qt::AlignVCenter | Qt::TextWordWrap, m_text );
     }
 }
 
 CWLoadingWidget::~CWLoadingWidget()
 {
-    if( m_toolsPixmap )
-        delete m_toolsPixmap;
-    if( m_logoPixmap )
-        delete m_logoPixmap;
-    if( m_topRightPixmap )
-        delete m_topRightPixmap;
-    if( m_barsPixmap )
-        delete m_barsPixmap;
-    if( m_toolsPixmapEffect )
-        delete m_toolsPixmapEffect;
-
+    delete m_toolsPixmap;
+    delete m_logoPixmap;
+    delete m_topRightPixmap;
+    delete m_barsPixmap;
+    delete m_toolsPixmapEffect;
     delete m_buffer;
 
     m_toolsPixmap = 0L;
