@@ -41,7 +41,6 @@ DiffModel::DiffModel( const QString& source, const QString& destination ) :
 	m_sourceRevision( "" ),
 	m_destinationRevision( "" ),
 	m_appliedCount( 0 ),
-	m_modified( false ),
 	m_diffIndex( 0 ),
 	m_selectedDifference( 0 ),
 	m_blended( false )
@@ -62,7 +61,6 @@ DiffModel::DiffModel() :
 	m_sourceRevision( "" ),
 	m_destinationRevision( "" ),
 	m_appliedCount( 0 ),
-	m_modified( false ),
 	m_diffIndex( 0 ),
 	m_selectedDifference( 0 ),
 	m_blended( false )
@@ -122,7 +120,6 @@ DiffModel& DiffModel::operator=( const DiffModel& model )
 		m_destinationTimestamp = model.m_destinationTimestamp;
 		m_destinationRevision = model.m_destinationRevision;
 		m_appliedCount = model.m_appliedCount;
-		m_modified = model.m_modified;
 
 		m_diffIndex = model.m_diffIndex;
 		m_selectedDifference = model.m_selectedDifference;
@@ -140,6 +137,9 @@ bool DiffModel::operator<( const DiffModel& model )
 
 int DiffModel::localeAwareCompareSource( const DiffModel& model )
 {
+	kDebug(8101) << "Path: " << model.m_sourcePath << endl;
+	kDebug(8101) << "File: " << model.m_sourceFile << endl;
+
 	int result = m_sourcePath.localeAwareCompare( model.m_sourcePath );
 
 	if ( result == 0 )
@@ -180,9 +180,9 @@ QString DiffModel::recreateDiff() const
 
 Difference* DiffModel::firstDifference()
 {
-	kDebug( 8101 ) << "DiffModel::firstDifference()" << endl;
+	kDebug(8101) << "DiffModel::firstDifference()" << endl;
 	m_diffIndex = 0;
-	kDebug( 8101 ) << "m_diffIndex = " << m_diffIndex << endl;
+	kDebug(8101) << "m_diffIndex = " << m_diffIndex << endl;
 
 	m_selectedDifference = m_differences[ m_diffIndex ];
 
@@ -191,9 +191,9 @@ Difference* DiffModel::firstDifference()
 
 Difference* DiffModel::lastDifference()
 {
-	kDebug( 8101 ) << "DiffModel::lastDifference()" << endl;
+	kDebug(8101) << "DiffModel::lastDifference()" << endl;
 	m_diffIndex = m_differences.count() - 1;
-	kDebug( 8101 ) << "m_diffIndex = " << m_diffIndex << endl;
+	kDebug(8101) << "m_diffIndex = " << m_diffIndex << endl;
 
 	m_selectedDifference = m_differences[ m_diffIndex ];
 
@@ -202,17 +202,17 @@ Difference* DiffModel::lastDifference()
 
 Difference* DiffModel::prevDifference()
 {
-	kDebug( 8101 ) << "DiffModel::prevDifference()" << endl;
+	kDebug(8101) << "DiffModel::prevDifference()" << endl;
 	if ( m_diffIndex > 0 && --m_diffIndex < m_differences.count() )
 	{
-		kDebug( 8101 ) << "m_diffIndex = " << m_diffIndex << endl;
+		kDebug(8101) << "m_diffIndex = " << m_diffIndex << endl;
 		m_selectedDifference = m_differences[ m_diffIndex ];
 	}
 	else
 	{
 		m_selectedDifference = 0;
 		m_diffIndex = 0;
-		kDebug( 8101 ) << "m_diffIndex = " << m_diffIndex << endl;
+		kDebug(8101) << "m_diffIndex = " << m_diffIndex << endl;
 	}
 
 	return m_selectedDifference;
@@ -220,17 +220,17 @@ Difference* DiffModel::prevDifference()
 
 Difference* DiffModel::nextDifference()
 {
-	kDebug( 8101 ) << "DiffModel::nextDifference()" << endl;
+	kDebug(8101) << "DiffModel::nextDifference()" << endl;
 	if (  ++m_diffIndex < m_differences.count() )
 	{
-		kDebug( 8101 ) << "m_diffIndex = " << m_diffIndex << endl;
+		kDebug(8101) << "m_diffIndex = " << m_diffIndex << endl;
 		m_selectedDifference = m_differences[ m_diffIndex ];
 	}
 	else
 	{
 		m_selectedDifference = 0;
 		m_diffIndex = 0; // just for safety...
-		kDebug( 8101 ) << "m_diffIndex = " << m_diffIndex << endl;
+		kDebug(8101) << "m_diffIndex = " << m_diffIndex << endl;
 	}
 
 	return m_selectedDifference;
@@ -298,6 +298,20 @@ void DiffModel::addDiff( Difference* diff )
 	m_differences.append( diff );
 }
 
+bool DiffModel::hasUnsavedChanges( void ) const
+{
+	DifferenceListConstIterator diffIt = m_differences.begin();
+	DifferenceListConstIterator endIt  = m_differences.end();
+
+	for ( ; diffIt != endIt; ++diffIt )
+	{
+		if ( (*diffIt)->isUnsaved() )
+			return true;
+	}
+
+	return false;
+}
+
 void DiffModel::applyDifference( bool apply )
 {
 	if ( apply && !m_selectedDifference->applied() )
@@ -305,43 +319,20 @@ void DiffModel::applyDifference( bool apply )
 	else if ( !apply && m_selectedDifference->applied() )
 		m_appliedCount--;
 
-	bool modified;
-
-	// Not setting the m_modified yet so i can still query the current
-	// modified status from the slot that is connected to the signal
-	if ( m_appliedCount == 0 )
-		modified = false;
-	else
-		modified = true;
-
-	emit setModified( modified );
-
-	m_modified = modified;
-
 	m_selectedDifference->apply( apply );
 }
 
 void DiffModel::applyAllDifferences( bool apply )
 {
-	bool modified;
-
-	// Not setting the m_modified yet so i can still query the current
-	// modified status from the slot that is connected to the signal
 	if ( apply )
 	{
 		m_appliedCount = m_differences.count();
-		modified = true;
 	}
 	else
 	{
 		m_appliedCount = 0;
-		modified = false;
 	}
 
-	emit setModified( modified );
-
-	m_modified = modified;
-
 	DifferenceListIterator diffIt = m_differences.begin();
 	DifferenceListIterator dEnd   = m_differences.end();
 	
@@ -351,15 +342,6 @@ void DiffModel::applyAllDifferences( bool apply )
 	}
 }
 
-void DiffModel::slotSetModified( bool modified )
-{
-	// Not setting the m_modified yet so i can still query the current
-	// modified status from the slot that is connected to the signal
-	emit setModified( modified );
-
-	m_modified = modified;
-}
-
 bool DiffModel::setSelectedDifference( Difference* diff )
 {
 	kDebug(8101) << "diff = " << diff << endl;
@@ -371,13 +353,11 @@ bool DiffModel::setSelectedDifference( Difference* diff )
 			return false;
 		// Do not set m_diffIndex if it cant be found
 		m_diffIndex = m_differences.findIndex( diff );
-		kDebug( 8101 ) << "m_diffIndex = " << m_diffIndex << endl;
+		kDebug(8101) << "m_diffIndex = " << m_diffIndex << endl;
 		m_selectedDifference = diff;
 	}
 
 	return true;
 }
 
-#include "diffmodel.moc"
-
 /* vim: set ts=4 sw=4 noet: */
