@@ -3,7 +3,7 @@
   This file is based on the one from KBabel
 
   Copyright (C) 1999-2000 by Matthias Kiefer <matthias.kiefer@gmx.de>
-		2001-2003 by Stanislav Visnovsky <visnovsky@kde.org>
+                2001-2003 by Stanislav Visnovsky <visnovsky@kde.org>
                 2006 by Nicolas GOUTTE <nicolasg@snafu.de>
                 2007 by Nick Shaforostoff <shafff@ukr.net>
 
@@ -53,13 +53,13 @@
 #include <kgenericfactory.h>
 #include <klocale.h>
 
-#include "pluralformtypes_enum.h"
 #include "catalogitem.h"
 
-//K_EXPORT_COMPONENT_FACTORY( kbabel_gettextimport, KGenericFactory<GettextImportPlugin> ( "kbabelgettextimportfilter" ) )
-
 using namespace GettextCatalog;
 
+// GettextImportPlugin::GettextImportPlugin(ExtraDataSaver* extraDataSaver)
+//    : CatalogImportPlugin()
+//    , _extraDataSaver(extraDataSaver)
 GettextImportPlugin::GettextImportPlugin()
    : CatalogImportPlugin()
    , _rxMsgCtxt          ("^msgctxt\\s*\".*\"$")
@@ -86,37 +86,16 @@ GettextImportPlugin::GettextImportPlugin()
 {
 }
 
-ConversionStatus GettextImportPlugin::load(const QString& filename)
+ConversionStatus GettextImportPlugin::load(QIODevice* device)
 {
    _testBorked=false;
-   if (KDE_ISUNLIKELY(filename.isEmpty()))
-   {
-      kDebug() << "fatal error: empty filename to open";
-      return NO_FILE;
-   }
-
-   QFileInfo info(filename);
-
-   if(KDE_ISUNLIKELY( !info.exists() || info.isDir()) )
-      return NO_FILE;
-
-   if(KDE_ISUNLIKELY( !info.isReadable() ))
-      return NO_PERMISSIONS;
-
-   QFile file(filename);
-
-   if (KDE_ISUNLIKELY( !file.open(QIODevice::ReadOnly) ))
-      return NO_PERMISSIONS;
-
-
-   QByteArray ba = file.readAll();
-   file.close();
+   _errorLine=0;
 
    // find codec for file
    //    bool hadCodec;
-   QTextCodec* codec=codecForArray( ba/*, &hadCodec*/ );
-
-   QTextStream stream(ba,QIODevice::ReadOnly);
+   QTextCodec* codec=codecForDevice(device/*, &hadCodec*/ );
+   QTextStream stream(device);
+   stream.seek(0);
    stream.setCodec(codec);
 
    //QIODevice *dev = stream.device();
@@ -124,13 +103,12 @@ ConversionStatus GettextImportPlugin::load(const QString& filename)
 
    // if somethings goes wrong with the parsing, we don't have deleted the old contents
    CatalogItem tempHeader;
-   QStringList tempObsolete;
 
-   //kDebug() << "start parsing...";
+   kDebug() << "start parsing...";
    QTime aaa;
    aaa.start();
    // first read header
-   const ConversionStatus status = readHeader(stream);
+   const ConversionStatus status = readEntry(stream);
 
    bool recoveredErrorInHeader = false;
    if (KDE_ISUNLIKELY( status == RECOVERED_PARSE_ERROR ))
@@ -140,14 +118,14 @@ ConversionStatus GettextImportPlugin::load(const QString& filename)
    }
    else if (KDE_ISUNLIKELY( status != OK ))
    {
-//       emit signalClearProgressBar();
-      kDebug() << "Parse error in header entry";
+      kWarning() << "Parse error in header entry";
       return status;
    }
 
-   kDebug() << "HEADER MSGID: " << _msgid;
-   kDebug() << "HEADER MSGSTR: " << _msgstr;
-   if (KDE_ISUNLIKELY( !_msgid.isEmpty() && !_msgid.first().isEmpty() ))
+   bool reconstructedHeader=!_msgid.isEmpty() && !_msgid.first().isEmpty();
+   //kWarning() << "HEADER MSGID: " << _msgid;
+   //kWarning() << "HEADER MSGSTR: " << _msgstr;
+   if (KDE_ISUNLIKELY( reconstructedHeader ))
    {
       // The header must have an empty msgid
       kWarning() << "Header entry has non-empty msgid. Creating a temporary header! " << _msgid;
@@ -188,32 +166,25 @@ ConversionStatus GettextImportPlugin::load(const QString& filename)
    bool recoveredError=false;
    bool docbookFile=false;
 
+   ExtraDataSaver _extraDataSaver;
+   ConversionStatus success=OK;
    while( !stream.atEnd() )
    {
+      if (reconstructedHeader)
+         reconstructedHeader=false;
+      else
+         success=readEntry(stream);
 
-      const ConversionStatus success=readEntry(stream);
       if(KDE_ISLIKELY(success==OK))
       {
          if( _obsolete )
-               tempObsolete.append(_comment);
+            _extraDataSaver(_comment);
          else
          {
             CatalogItem tempCatItem;
-            if (KDE_ISUNLIKELY( _gettextPluralForm ))
-            {
-                tempCatItem.setPluralFormType(Gettext);
-                tempCatItem.setMsgidPlural( _msgid );
-                tempCatItem.setMsgstrPlural( _msgstr );
-            }
-            else
-            {
-                if (KDE_ISUNLIKELY( _msgid.first().startsWith("_n: ") ))
-                    tempCatItem.setPluralFormType(KDESpecific);
-                else
-                    tempCatItem.setPluralFormType(NoPluralForm);
-                tempCatItem.setMsgid( _msgid );
-                tempCatItem.setMsgstr( _msgstr );
-            }
+            tempCatItem.setPlural(_gettextPluralForm);
+            tempCatItem.setMsgid( _msgid );
+            tempCatItem.setMsgstr( _msgstr );
             tempCatItem.setMsgctxt( _msgctxt );
             tempCatItem.setComment( _comment );
 
@@ -231,21 +202,9 @@ ConversionStatus GettextImportPlugin::load(const QString& filename)
          errorIndex.append(counter);
 
             CatalogItem tempCatItem;
-            if (KDE_ISUNLIKELY( _gettextPluralForm ))
-            {
-                tempCatItem.setPluralFormType(Gettext);
-                tempCatItem.setMsgidPlural( _msgid );
-                tempCatItem.setMsgstrPlural( _msgstr );
-            }
-            else
-            {
-                if (KDE_ISUNLIKELY( _msgid.first().startsWith("_n: ") ))
-                    tempCatItem.setPluralFormType(KDESpecific);
-                else
-                    tempCatItem.setPluralFormType(NoPluralForm);
-                tempCatItem.setMsgid( _msgid );
-                tempCatItem.setMsgstr( _msgstr );
-            }
+            tempCatItem.setPlural(_gettextPluralForm);
+            tempCatItem.setMsgid( _msgid );
+            tempCatItem.setMsgstr( _msgstr );
             tempCatItem.setMsgctxt( _msgctxt );
             tempCatItem.setComment( _comment );
 
@@ -260,16 +219,15 @@ ConversionStatus GettextImportPlugin::load(const QString& filename)
       }
       else
       {
-         kWarning() << "Unknown success status, assumig parse error " << success;
+         kDebug() << "Unknown success status, assumig parse error " << success;
          return PARSE_ERROR;
       }
       counter++;
 
    }
 
-
    // TODO: can we check that there is no useful entry?
-   if (KDE_ISUNLIKELY( !counter ))
+   if (KDE_ISUNLIKELY( !counter && !recoveredErrorInHeader ))
    {
       // Empty file? (Otherwise, there would be a try of getting an entry and the count would be 1 !)
       kDebug() << " Empty file?";
@@ -280,16 +238,15 @@ ConversionStatus GettextImportPlugin::load(const QString& filename)
 
    // We have successfully loaded the file (perhaps with recovered errors)
 
-   kDebug() << " done in " << aaa.elapsed() << endl;
+//    qWarning() << " done in " << aaa.elapsed() <<_extraDataSaver->extraData.size() << endl;
 
    setGeneratedFromDocbook(docbookContent || docbookFile);
    setHeader(tempHeader);
-   setCatalogExtraData(tempObsolete);
+   setCatalogExtraData(_extraDataSaver.extraData);
    setErrorIndex(errorIndex);
-   kWarning()<<"_trailingNewLines"<<_trailingNewLines;
-//   setFileCodec(codec);
-//   setMimeTypes( "text/x-gettext-translation" );
-
+   //setFileCodec(codec);
+   //setMimeTypes( "text/x-gettext-translation" );
+#if 0
    if (KDE_ISUNLIKELY( recoveredErrorInHeader ))
    {
       kDebug() << " Returning: header error";
@@ -301,20 +258,23 @@ ConversionStatus GettextImportPlugin::load(const QString& filename)
       return RECOVERED_PARSE_ERROR;
    }
    else
+#endif
    {
       kDebug() << " Returning: OK! :-)";
       return OK;
    }
 }
 
-QTextCodec* GettextImportPlugin::codecForArray(QByteArray& array/*, bool* hadCodec*/)
+QTextCodec* GettextImportPlugin::codecForDevice(QIODevice* device/*, bool* hadCodec*/)
 {
-    QTextStream stream( array, QIODevice::ReadOnly );
+    QTextStream stream( device );
+    stream.seek(0);
+    _errorLine=0;
     stream.setCodec( "UTF-8" );
     stream.setAutoDetectUnicode(true); //this way we can
     QTextCodec* codec=stream.codec();  //detect UTF-16
 
-    ConversionStatus status = readHeader(stream);
+    ConversionStatus status = readEntry(stream);
     if (KDE_ISUNLIKELY( status!=OK && status != RECOVERED_PARSE_ERROR ))
     {
         kDebug() << "wasn't able to read header";
@@ -357,28 +317,20 @@ QTextCodec* GettextImportPlugin::codecForArray(QByteArray& array/*, bool* hadCod
     return codec;//UTF-8
 }
 
-ConversionStatus GettextImportPlugin::readHeader(QTextStream& stream)
+ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
 {
-   int filePos = stream.device()->pos();
-   ConversionStatus status=readEntry(stream);
-
-   if(KDE_ISLIKELY( status==OK || status==RECOVERED_PARSE_ERROR ))
-   {
-      // test if this is the header
-      if(!_msgid.first().isEmpty())
-         stream.device()->seek( filePos );
-      return status;
-   }
-
-   return PARSE_ERROR;
+   ConversionStatus result=readEntryRaw(stream);
+   _msgstr.replaceInStrings("\\\"","\"");
+   _msgid.replaceInStrings("\\\"","\"");
+   _msgctxt.replace("\\\"","\"");
+   return result;
 }
 
-ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
+ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
 {
    //kDebug() << " START";
    enum {Begin,Comment,Msgctxt,Msgid,Msgstr} part=Begin;
 
-   //QString line;
    _trailingNewLines=0;
    bool error=false;
    bool recoverableError=false;
@@ -392,15 +344,22 @@ ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
    _gettextPluralForm=false;
    _obsolete=false;
 
-
    QStringList::Iterator msgstrIt=_msgstr.begin();
+   QString line;
 
    while( !stream.atEnd() )
    {
+       _errorLine++;
        //line=stream.readLine();
-       QString line(stream.readLine());
+       if (!_bufferedLine.isEmpty())
+       {
+            line=_bufferedLine;
+            _bufferedLine.clear();
+       }
+       else
+           line=stream.readLine();
 
-       //kDebug() << "Parsing line: " << line;
+       kDebug() << "Parsing line: " << line;
 
        if (KDE_ISUNLIKELY( line.startsWith( "<<<<<<<" ) || line.startsWith( "=======" ) || line.startsWith( ">>>>>>>" ) ))
        {
@@ -415,10 +374,12 @@ ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
 
        // remember wrapping state to save file nicely
        int len=line.length();
-       if (_maxLineLength<len)
-           _maxLineLength=len;
        if (len)
+       {
           _trailingNewLines=0;
+         if (_maxLineLength<len && line.at(0)!='#')
+           _maxLineLength=len;
+       }
        else
           ++_trailingNewLines;
 
@@ -431,9 +392,9 @@ ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
 
            if(line.startsWith(_obsoleteStart))
            {
-              _obsolete=true;
-	      part=Comment;
-	      _comment=line;
+               _obsolete=true;
+               part=Comment;
+               _comment=line;
            }
            else if(line.startsWith('#'))
            {
@@ -461,7 +422,7 @@ ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
                (*(_msgid).begin())=line;
 
            }
-		     // one of the quotation marks is missing
+           // one of the quotation marks is missing
            else if(KDE_ISUNLIKELY( /*_testBorked&&*/ line.contains( _rxMsgIdBorked ) ))
            {
                part=Msgid;
@@ -485,12 +446,11 @@ ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
        else if(part==Comment)
        {
             if(!len && _obsolete ) return OK;
-	    if(!len)
-	       continue;
+            if(!len) continue;
             else if(line.startsWith(_obsoleteStart))
             {
                _comment+=('\n'+line);
-	       _obsolete=true;
+               _obsolete=true;
             }
             else if(line.startsWith('#'))
             {
@@ -751,7 +711,13 @@ ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
                msgstrIt=_msgstr.end();
                --msgstrIt;
             }
-	    else if(KDE_ISUNLIKELY(/*_testBorked&&*/ _gettextPluralForm && ( line.contains( _rxMsgStrPluralBorked ) ) ))
+            else if ( line.startsWith( '#' ) || line.startsWith( "msgid" ) )
+            {
+               _errorLine--;
+               _bufferedLine=line;
+               break;
+            }
+            else if(KDE_ISUNLIKELY(/*_testBorked&&*/ _gettextPluralForm && ( line.contains( _rxMsgStrPluralBorked ) ) ))
             {
                // remove quotes at beginning and the end of the lines
                line.remove(QRegExp("^msgstr\\[[0-9]\\]\\s*\"?"));
@@ -766,7 +732,7 @@ ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
             }
             else if(line.startsWith("msgstr"))
             {
-               kDebug() << "Another msgstr found after a msgstr while parsing: " << _msgstr.last();
+               kDebug() << "Another msgstr found after a msgstr while parsing: " << line << _msgstr.last();
                error=true;
                break;
             }
