@@ -1,12 +1,15 @@
 /* ****************************************************************************
-  This file is part of KAider
+  This file is part of Lokalize
 
-  Copyright (C) 2007 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2007-2009 by Nick Shaforostoff <shafff@ukr.net>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+  This program is free software; you can redistribute it and/or
+  modify it under the terms of the GNU General Public License as
+  published by the Free Software Foundation; either version 2 of
+  the License or (at your option) version 3 or any later version
+  accepted by the membership of KDE e.V. (or its successor approved
+  by the membership of KDE e.V.), which shall act as a proxy 
+  defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,19 +17,7 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
-  In addition, as a special exception, the copyright holders give
-  permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
-  combinations including the two.  You must obey the GNU General
-  Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
-  your version of the file, but you are not obligated to do so.  If
-  you do not wish to do so, delete this exception statement from
-  your version.
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **************************************************************************** */
 
@@ -287,10 +278,10 @@ static void addTerms(Glossary* glo)
         "            <titleStmt>\n"
         "                <title>Your Team Glossary</title>\n"
         "            </titleStmt>\n"
+        "            <sourceDesc>\n"
+        "                <p>Lokalize</p>\n"
+        "            </sourceDesc>\n"
         "        </fileDesc>\n"
-        "        <encodingDesc>\n"
-        "            <p type=\"DCSName\">SYSTEM &quot;TBXDCSv05b.xml&quot;</p>\n"
-        "        </encodingDesc>\n"
         "    </martifHeader>\n"
         "    <text>\n"
         "        <body>\n"
@@ -393,7 +384,7 @@ static void addTerms(Glossary* glo)
 
     //Qt isn't perfect
     out.replace("\n\n","\n");
-    out.replace("\n","\n            ");
+    out.replace('\n',"\n            ");
 
     out+=
 "\n        </body>"
@@ -436,7 +427,7 @@ QVariant GlossaryModel::headerData( int section, Qt::Orientation /*orientation*/
     switch (section)
     {
 //         case ID: return i18nc("@title:column","ID");
-        case English: return i18nc("@title:column Original text","Original");;
+        case English: return i18nc("@title:column Original text","Source");;
         case Target: return i18nc("@title:column Text in target language","Target");
         case SubjectField: return i18nc("@title:column","Subject Field");
     }
@@ -448,18 +439,14 @@ QVariant GlossaryModel::data(const QModelIndex& index,int role) const
     if (role!=Qt::DisplayRole)
         return QVariant();
 
-//     kDebug()<<index.row();
-//     kDebug()<<Project::instance()->glossary()->termList.size();
     switch (index.column())
     {
-//         case ID: return Project::instance()->glossary()->termList.at(index.row()).id/*index.row()+1*/;
         case English: return Project::instance()->glossary()->termList.at(index.row()).english.join("\n");
         case Target: return Project::instance()->glossary()->termList.at(index.row()).target.join("\n");
         case SubjectField: 
         {
             const Glossary* glo=Project::instance()->glossary();
             int field=glo->termList.at(index.row()).subjectField;
-
             return glo->subjectFields.at(field);
         }
     }
@@ -472,7 +459,7 @@ QVariant GlossaryModel::data(const QModelIndex& index,int role) const
 
 QString Glossary::generateNewId()
 {
-    //generate uniq ID
+    // generate unique ID
     int id=0;
     QList<int> idlist;
     const QList<TermEntry>& termList=Project::instance()->glossary()->termList;
@@ -608,3 +595,5 @@ bool GlossaryModel::appendRow(const QString& _english,const QString& _target)
 }
 
 //END EDITING
+
+#include "glossary.moc"
