@@ -1,12 +1,15 @@
 /* ****************************************************************************
-  This file is part of KAider
+  This file is part of Lokalize
 
-  Copyright (C) 2007 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2007-2009 by Nick Shaforostoff <shafff@ukr.net>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+  This program is free software; you can redistribute it and/or
+  modify it under the terms of the GNU General Public License as
+  published by the Free Software Foundation; either version 2 of
+  the License or (at your option) version 3 or any later version
+  accepted by the membership of KDE e.V. (or its successor approved
+  by the membership of KDE e.V.), which shall act as a proxy 
+  defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,28 +17,18 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
-  In addition, as a special exception, the copyright holders give
-  permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
-  combinations including the two.  You must obey the GNU General
-  Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
-  your version of the file, but you are not obligated to do so.  If
-  you do not wish to do so, delete this exception statement from
-  your version.
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **************************************************************************** */
 
-#ifndef SETTINGSCONTROLLER_H
-#define SETTINGSCONTROLLER_H
+#ifndef PREFS_H
+#define PREFS_H
 
 #include <QLineEdit>
 class KEditListBox;
 
+namespace Kross {class ActionCollectionView;}
+
 /**
  * Singleton that manages cfgs for Lokalize and projects
  */
@@ -51,7 +44,6 @@ public slots:
     void slotSettings();
 
     void projectOpen(QString path=QString());
-    void projectCreate();
     void projectConfigure();
     void reflectRelativePathsHack();
 
@@ -61,6 +53,7 @@ signals:
 private:
     KEditListBox* m_scriptsRelPrefWidget; //HACK to get relative filenames in the project file
     KEditListBox* m_scriptsPrefWidget;
+    Kross::ActionCollectionView* m_projectActionsView;
 
 private:
     static SettingsController* _instance;
@@ -80,9 +73,24 @@ Q_OBJECT
 public:
     RelPathSaver(QWidget* p):QLineEdit(p){}
 public slots:
-    void setText ( const QString & );
+    void setText(const QString&);
 };
 
 
+#include <kross/ui/view.h>
+class ScriptsView: public Kross::ActionCollectionView
+{
+Q_OBJECT
+public:
+    ScriptsView(QWidget* parent);
+
+// public slots:
+//     void addScsetText(const QString&);
+
+    void dragEnterEvent(QDragEnterEvent* event);
+    void dropEvent(QDropEvent* event);
+
+};
+
 
 #endif
