@@ -2,7 +2,7 @@
 
 ###############################################################################
 # Sanity checks CMakeLists.txt files.                                         #
-# Copyright (C) 2006-2008 by Allen Winter <winter@kde.org>                    #
+# Copyright (C) 2006-2009 by Allen Winter <winter@kde.org>                    #
 # Copyright (C) 2008 by Laurent Montel <montel@kde.org>                       #
 #                                                                             #
 # This program is free software; you can redistribute it and/or modify        #
@@ -23,6 +23,10 @@
 #
 # A program to check KDE CMakeLists.txt files for common errors.
 #
+
+# This program needs a rewrite.. it assumes that each CMake command is
+# all on 1 line.  So stuff can easily fall through the cracks -- Allen
+
 # Program options:
 #   --help:          display help message and exit
 #   --version:       display version information and exit
@@ -127,17 +131,19 @@ sub processFile() {
       }
       if ($line =~ m/macro_log_feature\(\s*([A-Z0-9_]*).*\)/i) {
 	$pack = lc($1);
-	if ($pack !~ m/^(compositing|pcre|boost|gpgme|x11|strigiqtdbusclient|xsltproc)_/ &&
+	if ($pack !~ m/^(compositing|pcre|gpgme|libical|sqlite|strigiqtdbusclient|xsltproc|qt_qtopengl|ggzconfig)_/ &&
+	    $pack !~ m/x11_.*_found/ &&
 	    $pack !~ m/true/i && $pack !~ m/false/i) {
+	  $pack =~ s/_xcb//;
 	  $pack =~ s/have_//;
 	  $pack =~ s/_found//;
 	  $pack =~ s/_video//;
 	  if (!defined($optpacks{$pack}{'name'})) {
-	    if ($pack !~ m/^(kwin_compositing|current_alsa)/) {
+#	    if ($pack !~ m/^(kwin_compositing|current_alsa)/) {
 	      $issues++;
 	      &printIssue($line,$linecnt,"macro_log_feature($pack) used without macro_optional_find_package()");
 	    }
-	  }
+#	  }
 	  $optpacks{$pack}{'log'} = 1;
 	}
       }
@@ -283,7 +289,7 @@ sub processFile() {
 			  '\sFILES\sDESTINATION',
 			  'missing list of files between FILES and DESTINATION');
     $issues += &checkLine($line,$linecnt,
-			  'TARGETS[[:space:]]DESTINATION',
+			  '\sTARGETS\sDESTINATION',
 			  'missing list of files between TARGETS and DESTINATION');
 
     $issues += &checkLine($line,$linecnt,
@@ -299,7 +305,7 @@ sub processFile() {
     $issues += &checkLine($line,$linecnt,
 			  '-fexceptions',
 			  'replace "-fexceptions" with "${KDE4_ENABLE_EXCEPTIONS}"');
-    if ($in !~ m+/(phonon|okular|kopete|kdevelop)/+) {
+    if ($in !~ m+/(phonon|okular|kopete|kdevelop|libkdegames)/+) {
       $issues +=
         &checkLine($line,$linecnt,
                    'set_target_properties.*PROPERTIES.*[[:space:]]VERSION[[:space:]][[:digit:]]',
@@ -402,119 +408,124 @@ sub processFile() {
 		   'target_link_libraries.*[[:space:]]kio[\s/)]',
 		   'replace "kio" with "${KDE4_KIO_LIBS}"');
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]kdesu[\s/)]',
-            'replace "kdesu" with "${KDE4_KDESU_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]kdesu[\s/)]',
+		   'replace "kdesu" with "${KDE4_KDESU_LIBS}"');
 
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]khtml[\s/)]',
-            'replace "khtml" with "${KDE4_KHTML_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]khtml[\s/)]',
+		   'replace "khtml" with "${KDE4_KHTML_LIBS}"');
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]kparts[\s/)]',
-            'replace "kparts" with "${KDE4_KPARTS_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]kparts[\s/)]',
+		   'replace "kparts" with "${KDE4_KPARTS_LIBS}"');
 
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]kde3support[\s/)]',
-            'replace "kde3support" with "${KDE4_KDE3SUPPORT_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]kde3support[\s/)]',
+		   'replace "kde3support" with "${KDE4_KDE3SUPPORT_LIBS}"');
 
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]kutils[\s/)]',
-            'replace "kutils" with "${KDE4_KUTILS_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]kutils[\s/)]',
+		   'replace "kutils" with "${KDE4_KUTILS_LIBS}"');
 
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]kdnssd[\s/)]',
-            'replace "kdnssd" with "${KDE4_KDNSSD_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]kdnssd[\s/)]',
+		   'replace "kdnssd" with "${KDE4_KDNSSD_LIBS}"');
 
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]knewstuff2[\s/)]',
-            'replace "knewstuff2" with "${KDE4_KNEWSTUFF2_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]knewstuff2[\s/)]',
+		   'replace "knewstuff2" with "${KDE4_KNEWSTUFF2_LIBS}"');
 
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]knotifyconfig[\s/)]',
-            'replace "knotifyconfig" with "${KDE4_KNOTIFYCONFIG_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]knotifyconfig[\s/)]',
+		   'replace "knotifyconfig" with "${KDE4_KNOTIFYCONFIG_LIBS}"');
 
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]threadweaver[\s/)]',
-            'replace "threadweaver" with "${KDE4_THREADWEAVER_LIBRARIES}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]threadweaver[\s/)]',
+		   'replace "threadweaver" with "${KDE4_THREADWEAVER_LIBRARIES}"');
 
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]krosscore[\s/)]',
-            'replace "krosscore" with "${KDE4_KROSSCORE_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]krosscore[\s/)]',
+		   'replace "krosscore" with "${KDE4_KROSSCORE_LIBS}"');
 
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]krossui[\s/)]',
-            'replace "krossui" with "${KDE4_KROSSUI_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]krossui[\s/)]',
+		   'replace "krossui" with "${KDE4_KROSSUI_LIBS}"');
 
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]phonon[\s/)]',
-            'replace "phonon" with "${KDE4_PHONON_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]phonon[\s/)]',
+		   'replace "phonon" with "${PHONON_LIBRARY}"');
 
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]kaudiodevicelist[\s/)]',
-            'replace "kaudiodevicelist" with "${KDE4_KAUDIODEVICELIST_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]kaudiodevicelist[\s/)]',
+		   'replace "kaudiodevicelist" with "${KDE4_KAUDIODEVICELIST_LIBS}"');
 
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]solidifaces[\s/)]',
-            'replace "solidifaces" with "${KDE4_SOLIDIFACES_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]solidifaces[\s/)]',
+		   'replace "solidifaces" with "${KDE4_SOLIDIFACES_LIBS}"');
 
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]solid[\s/)]',
-            'replace "solid" with "${KDE4_SOLID_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]solid[\s/)]',
+		   'replace "solid" with "${KDE4_SOLID_LIBS}"');
 
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]ktexteditor[\s/)]',
-            'replace "ktexteditor" with "${KDE4_KTEXTEDITOR_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]ktexteditor[\s/)]',
+		   'replace "ktexteditor" with "${KDE4_KTEXTEDITOR_LIBS}"');
 
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]kfile[\s/)]',
-            'replace "kfile" with "${KDE4_KFILE_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]kfile[\s/)]',
+		   'replace "kfile" with "${KDE4_KFILE_LIBS}"');
 
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]knepomuk[\s/)]',
-            'replace "knepomuk" with "${KDE4_KNEPOMUK_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]knepomuk[\s/)]',
+		   'replace "knepomuk" with "${KDE4_KNEPOMUK_LIBS}"');
 
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]kmetadata[\s/)]',
-            'replace "kmetadata" with "${KDE4_KMETADATA_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]kmetadata[\s/)]',
+		   'replace "kmetadata" with "${KDE4_KMETADATA_LIBS}"');
 
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]kjs[\s/)]',
-            'replace "kjs" with "${KDE4_KJS_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]kjs[\s/)]',
+		   'replace "kjs" with "${KDE4_KJS_LIBS}"');
 
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]kjsapi[\s/)]',
-            'replace "kjsapi" with "${KDE4_KJSAPI_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]kjsapi[\s/)]',
+		   'replace "kjsapi" with "${KDE4_KJSAPI_LIBS}"');
 
       $issues +=
-    &checkLine($line,$linecnt,
-            'target_link_libraries.*[[:space:]]kformula[\s/)]',
-            'replace "kformula" with "${KDE4_KFORMULA_LIBS}"');
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]kformula[\s/)]',
+		   'replace "kformula" with "${KDE4_KFORMULA_LIBS}"');
 
       $issues +=
         &checkLine($line,$linecnt,
                    'target_link_libraries.*[[:space:]]plasma[\s/)]',
                    'replace "plasma" with "${KDE4_PLASMA_LIBS}"');
 
+      $issues +=
+        &checkLine($line,$linecnt,
+                   'target_link_libraries.*[[:space:]]knotificationitem-1[\s/)]',
+                   'replace "knotificationitem-1" with "${KNOTIFICATIONITEM_LIBRARIES}"');
+
     }
 
     # kdepimlibs variables
@@ -543,6 +554,10 @@ sub processFile() {
 	&checkLine($line,$linecnt,
 		   'target_link_libraries.*[[:space:]]kcal[\s/)]',
 		   'replace "kcal" with "${KDE4_KCAL_LIBS}"');
+      $issues +=
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]kholidays[\s/)]',
+		   'replace "kholidays" with "${KDE4_KHOLIDAYS_LIBS}"');
       $issues +=
 	&checkLine($line,$linecnt,
 		   'target_link_libraries.*[[:space:]]kimap[\s/)]',
@@ -559,6 +574,10 @@ sub processFile() {
 	&checkLine($line,$linecnt,
 		   'target_link_libraries.*[[:space:]]kpimidentities[\s/)]',
 		   'replace "kpimidentities" with "${KDE4_KPIMIDENTITIES_LIBS}"');
+      $issues +=
+	&checkLine($line,$linecnt,
+		   'target_link_libraries.*[[:space:]]kpimtextedit[\s/)]',
+		   'replace "kpimtextedit" with "${KDE4_KPIMTEXTEDIT_LIBS}"');
       $issues +=
 	&checkLine($line,$linecnt,
 		   'target_link_libraries.*[[:space:]]kpimutils[\s/)]',
@@ -579,6 +598,10 @@ sub processFile() {
         &checkLine($line,$linecnt,
                    'target_link_libraries.*[[:space:]]mailtransport[\s/)]',
                    'replace "mailtransport" with "${KDE4_MAILTRANSPORT_LIBS}"');
+      $issues +=
+        &checkLine($line,$linecnt,
+                   'target_link_libraries.*[[:space:]]microblog[\s/)]',
+                   'replace "microblog" with "${KDE4_MICROBLOG_LIBS}"');
       $issues +=
 	&checkLine($line,$linecnt,
 		   'target_link_libraries.*[[:space:]]qgpgme[\s/)]',
@@ -589,7 +612,7 @@ sub processFile() {
                    'replace "syndication" with "${KDE4_SYNDICATION_LIBS}"');
     }
 
-    if ($line !~ m+(Plasma|Nepomuk|ACL|Alsa|PCRE|Boost|Gpgme|Kttsmodule|KdeSubversion)+ && $in !~ m+/(examples|qtonly)/+) {
+    if ($line !~ m+(Flex|Plasma|Nepomuk|ACL|Alsa|PCRE|Boost|Libical|Sqlite|Gpgme|Expat|Kttsmodule|KdeSubversion)+ && $in !~ m+/(examples|qtonly)/+) {
       $issues +=
 	&checkLine($line,$linecnt,
 		   '^\s*[Ff][Ii][Nn][Dd]_[Pp][Aa][Cc][Kk][Aa][Gg][Ee]\s*\(\s*[A-Za-z0-9_]*\s*\)',
@@ -641,10 +664,10 @@ sub processFile() {
     $issues++;
     &printIssue($line,$linecnt,"Missing macro_display_feature_log() command");
   }
-  if (!$top_of_module && $has_display_log == 1 && $in !~ m+/qtonly/+) {
-    $issues++;
-    &printIssue($line,$linecnt,"Do not put macro_display_feature_log() in a subdir CMakeLists.txt");
-  }
+  #if (!$top_of_module && $has_display_log == 1 && $in !~ m+/qtonly/+) {
+  #  $issues++;
+  #  &printIssue($line,$linecnt,"Do not put macro_display_feature_log() in a subdir CMakeLists.txt");
+  #}
   if ($nop != $ncp) {
     $issues++;
     &printIssue($line,$linecnt,"Mismatched parens");
