@@ -41,11 +41,10 @@ done
 # Project related configuration options
 #---------------------------------------------------------------------------
 PROJECT_NAME           = KDE
-PROJECT_NUMBER         = 4.2
+PROJECT_NUMBER         = 4.3
 OUTPUT_DIRECTORY       = apidocs
 CREATE_SUBDIRS         = NO
 OUTPUT_LANGUAGE        = English
-USE_WINDOWS_ENCODING   = NO
 BRIEF_MEMBER_DESC      = YES
 REPEAT_BRIEF           = YES
 ABBREVIATE_BRIEF       = "The \$name class" \
@@ -67,7 +66,6 @@ STRIP_FROM_INC_PATH    =
 SHORT_NAMES            = NO
 JAVADOC_AUTOBRIEF      = NO
 MULTILINE_CPP_IS_BRIEF = NO
-DETAILS_AT_TOP         = NO
 INHERIT_DOCS           = YES
 SEPARATE_MEMBER_PAGES  = NO
 TAB_SIZE               = 8
@@ -143,7 +141,7 @@ EXCLUDE_PATTERNS       = */.svn/* \
 EXAMPLE_PATH           = 
 EXAMPLE_PATTERNS       = *
 EXAMPLE_RECURSIVE      = NO
-IMAGE_PATH             = 
+IMAGE_PATH             = $PWD
 INPUT_FILTER           = 
 FILTER_PATTERNS        = 
 FILTER_SOURCE_FILES    = NO
@@ -222,8 +220,6 @@ DIRECTORY_GRAPH        = YES
 DOT_IMAGE_FORMAT       = png
 DOT_PATH               =
 DOTFILE_DIRS           =
-MAX_DOT_GRAPH_WIDTH    = 1024
-MAX_DOT_GRAPH_HEIGHT   = 1024
 MAX_DOT_GRAPH_DEPTH    = 1000
 DOT_TRANSPARENT        = NO
 DOT_MULTI_TARGETS      = NO
@@ -249,7 +245,7 @@ ALIASES = \
 	"maintainers=\xrefitem maintainers \"Maintainer(s)\" \"Maintainers\"" \
 	"port4=\xrefitem port4 \"KDE 4 Porting Guide\" \"KDE 4 Porting Guide\"" \
 	"glossary=\xrefitem glossary \"KDE 4 Glossary\" \"KDE 4 Glossary\"" \
-        "acronym=\b "\
+	"acronym=\b "\
 	"licenses=\xrefitem licenses \"License(s)\" \"Licenses\"" \
 	"short=@brief "\
 	"FIXME=\xrefitem fixme \"Fixme\" \"Fixme\"" \
@@ -378,61 +374,61 @@ PREDEFINED = DOXYGEN_SHOULD_SKIP_THIS \
 	THREADWEAVER_EXPORT="" \
 	YAHOO_EXPORT="" \
 \
-        KDE_DEPRECATED="" \
-        AKREGATOR_EXPORT_DEPRECATED="" \
-        AKREGATORINTERFACES_EXPORT_DEPRECATED="" \
-        GPGMEPP_EXPORT_DEPRECATED="" \            
-        KABC_DIRECTORY_EXPORT_DEPRECATED="" \     
-        KABC_EXPORT_DEPRECATED="" \               
-        KABC_FILE_CORE_EXPORT_DEPRECATED="" \     
-        KABC_LDAPKIO_EXPORT_DEPRECATED="" \
-        KABC_NET_EXPORT_DEPRECATED="" \
-        KABINTERFACES_EXPORT_DEPRECATED="" \
-        KCDDB_EXPORT_DEPRECATED="" \
-        KCM_KRESOURCES_EXPORT_DEPRECATED="" \
-        KDE3SUPPORT_EXPORT_DEPRECATED="" \
-        KDECORE_EXPORT_DEPRECATED="" \
-        KDEEDUUI_EXPORT_DEPRECATED="" \
-        KDEGAMES_EXPORT_DEPRECATED="" \
-        KDEUI_EXPORT_DEPRECATED="" \
-        KEDUVOCDOCUMENT_EXPORT_DEPRECATED="" \
-        KEXIV2_EXPORT_DEPRECATED="" \
-        KFILE_EXPORT_DEPRECATED="" \
-        KGGZGAMES_EXPORT_DEPRECATED="" \
-        KGGZMOD_EXPORT_DEPRECATED="" \
-        KGGZNET_EXPORT_DEPRECATED="" \
-        KHTML_EXPORT_DEPRECATED="" \
-        KIO_EXPORT_DEPRECATED="" \
-        KJSAPI_EXPORT_DEPRECATED="" \
-        KLEO_EXPORT_DEPRECATED="" \
-        KMAHJONGGLIB_EXPORT_DEPRECATED="" \
-        KMIME_EXPORT_DEPRECATED="" \
-        KNEWSTUFF_EXPORT_DEPRECATED="" \
-        KNTLM_EXPORT_DEPRECATED="" \
-        KOMMANDERCORE_EXPORT_DEPRECATED="" \
-        KPGP_EXPORT_DEPRECATED="" \
-        KPILOT_EXPORT_DEPRECATED="" \
-        KPTY_EXPORT_DEPRECATED="" \
-        KRESOURCES_EXPORT_DEPRECATED="" \
-        KSIEVE_EXPORT_DEPRECATED="" \
-        KTNEF_EXPORT_DEPRECATED="" \
-        LANCELOT_EXPORT_DEPRECATED="" \
-        LIBKDCRAW_EXPORT_DEPRECATED="" \
-        LIBKIPI_EXPORT_DEPRECATED="" \
-        LIBKSANE_EXPORT_DEPRECATED="" \
-        PHONON_EXPORT_DEPRECATED="" \
-        PLASMA_EXPORT_DEPRECATED="" \
-        QGPGME_EXPORT_DEPRECATED="" \
-        SCIENCE_EXPORT_DEPRECATED="" \
-        SOLID_EXPORT_DEPRECATED="" \
-        TASKMANAGER_EXPORT_DEPRECATED="" \
+	KDE_DEPRECATED="" \
+	AKREGATOR_EXPORT_DEPRECATED="" \
+	AKREGATORINTERFACES_EXPORT_DEPRECATED="" \
+	GPGMEPP_EXPORT_DEPRECATED="" \
+	KABC_DIRECTORY_EXPORT_DEPRECATED="" \
+	KABC_EXPORT_DEPRECATED="" \
+	KABC_FILE_CORE_EXPORT_DEPRECATED="" \
+	KABC_LDAPKIO_EXPORT_DEPRECATED="" \
+	KABC_NET_EXPORT_DEPRECATED="" \
+	KABINTERFACES_EXPORT_DEPRECATED="" \
+	KCDDB_EXPORT_DEPRECATED="" \
+	KCM_KRESOURCES_EXPORT_DEPRECATED="" \
+	KDE3SUPPORT_EXPORT_DEPRECATED="" \
+	KDECORE_EXPORT_DEPRECATED="" \
+	KDEEDUUI_EXPORT_DEPRECATED="" \
+	KDEGAMES_EXPORT_DEPRECATED="" \
+	KDEUI_EXPORT_DEPRECATED="" \
+	KEDUVOCDOCUMENT_EXPORT_DEPRECATED="" \
+	KEXIV2_EXPORT_DEPRECATED="" \
+	KFILE_EXPORT_DEPRECATED="" \
+	KGGZGAMES_EXPORT_DEPRECATED="" \
+	KGGZMOD_EXPORT_DEPRECATED="" \
+	KGGZNET_EXPORT_DEPRECATED="" \
+	KHTML_EXPORT_DEPRECATED="" \
+	KIO_EXPORT_DEPRECATED="" \
+	KJSAPI_EXPORT_DEPRECATED="" \
+	KLEO_EXPORT_DEPRECATED="" \
+	KMAHJONGGLIB_EXPORT_DEPRECATED="" \
+	KMIME_EXPORT_DEPRECATED="" \
+	KNEWSTUFF_EXPORT_DEPRECATED="" \
+	KNTLM_EXPORT_DEPRECATED="" \
+	KOMMANDERCORE_EXPORT_DEPRECATED="" \
+	KPGP_EXPORT_DEPRECATED="" \
+	KPILOT_EXPORT_DEPRECATED="" \
+	KPTY_EXPORT_DEPRECATED="" \
+	KRESOURCES_EXPORT_DEPRECATED="" \
+	KSIEVE_EXPORT_DEPRECATED="" \
+	KTNEF_EXPORT_DEPRECATED="" \
+	LANCELOT_EXPORT_DEPRECATED="" \
+	LIBKDCRAW_EXPORT_DEPRECATED="" \
+	LIBKIPI_EXPORT_DEPRECATED="" \
+	LIBKSANE_EXPORT_DEPRECATED="" \
+	PHONON_EXPORT_DEPRECATED="" \
+	PLASMA_EXPORT_DEPRECATED="" \
+	QGPGME_EXPORT_DEPRECATED="" \
+	SCIENCE_EXPORT_DEPRECATED="" \
+	SOLID_EXPORT_DEPRECATED="" \
+	TASKMANAGER_EXPORT_DEPRECATED="" \
 \
-        Q_WS_X11="" \
-        Q_WS_WIN="" \
-        Q_WS_MAC="" \
+	Q_WS_X11="" \
+	Q_WS_WIN="" \
+	Q_WS_MAC="" \
 	Q_OS_UNIX="" \
-        Q_OS_WIN="" \
-        Q_OS_MACX="" \
+	Q_OS_WIN="" \
+	Q_OS_MACX="" \
 \
 	Q_SLOTS="slots" \
 	Q_SIGNALS="signals"
