@@ -1,11 +1,10 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2008                                               *
+ *   copyright (C) 2003-2009                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -15,22 +14,39 @@
 #include <kdebug.h>
 #include <klocale.h>
 
+/**
+ * Sets up an enum literal.
+ * @param parent    The parent of this UMLEnumLiteral.
+ * @param name      The name of this UMLEnumLiteral.
+ * @param id        The unique id given to this UMLEnumLiteral.
+ */
 UMLEnumLiteral::UMLEnumLiteral(UMLObject *parent,
                                const QString& name, Uml::IDType id)
-        : UMLClassifierListItem(parent, name, id)
+  : UMLClassifierListItem(parent, name, id)
 {
     m_BaseType = Uml::ot_EnumLiteral;
 }
 
-UMLEnumLiteral::UMLEnumLiteral(UMLObject *parent) : UMLClassifierListItem(parent)
+/**
+ * Sets up an enum literal.
+ * @param parent    The parent of this UMLEnumLiteral.
+ */
+UMLEnumLiteral::UMLEnumLiteral(UMLObject *parent)
+  : UMLClassifierListItem(parent)
 {
     m_BaseType = Uml::ot_EnumLiteral;
 }
 
+/**
+ * Destructor.
+ */
 UMLEnumLiteral::~UMLEnumLiteral()
 {
 }
 
+/**
+ * Overloaded '==' operator
+ */
 bool UMLEnumLiteral::operator==(const UMLEnumLiteral& rhs)
 {
     if ( this == &rhs )  {
@@ -42,11 +58,18 @@ bool UMLEnumLiteral::operator==(const UMLEnumLiteral& rhs)
     return true;
 }
 
+/**
+ * Copy the internal presentation of this object into the new
+ * object.
+ */
 void UMLEnumLiteral::copyInto(UMLObject *lhs) const
 {
     UMLClassifierListItem::copyInto(lhs);
 }
 
+/**
+ * Make a clone of this object.
+ */
 UMLObject* UMLEnumLiteral::clone() const
 {
     UMLEnumLiteral *clone = new UMLEnumLiteral((UMLObject *) parent());
@@ -55,17 +78,27 @@ UMLObject* UMLEnumLiteral::clone() const
     return clone;
 }
 
+/**
+ * Creates the <UML:EnumLiteral> XMI element.
+ */
 void UMLEnumLiteral::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
 {
     QDomElement attributeElement = UMLObject::save("UML:EnumerationLiteral", qDoc);
     qElement.appendChild( attributeElement );
 }
 
-bool UMLEnumLiteral::load(QDomElement& )
+/**
+ * Loads the <UML:EnumLiteral> XMI element (empty.)
+ */
+bool UMLEnumLiteral::load(QDomElement& element)
 {
+    Q_UNUSED(element);
     return true;
 }
 
+/**
+ * Display the properties configuration dialog for the enum literal.
+ */
 bool UMLEnumLiteral::showPropertiesDialog(QWidget* parent)
 {
     bool ok;
