@@ -1,39 +1,66 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2006                                               *
+ *   copyright (C) 2002-2009                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #include "usecase.h"
 
+/**
+ * Creates a UseCase object
+ *
+ * @param name   The name of the object.
+ * @param id     The id of the object.
+ */
 UMLUseCase::UMLUseCase(const QString & name, Uml::IDType id)
-        : UMLCanvasObject(name, id) {
+  : UMLCanvasObject(name, id)
+{
     init();
 }
 
-UMLUseCase::~UMLUseCase() {}
+/**
+ * Standard decstructor.
+ */
+UMLUseCase::~UMLUseCase()
+{
+}
 
-void UMLUseCase::init() {
+/**
+ * Initializes key variables of the class.
+ */
+void UMLUseCase::init()
+{
     m_BaseType = Uml::ot_UseCase;
 }
 
-UMLObject* UMLUseCase::clone() const {
+/**
+ * Make a clone of this object.
+ */
+UMLObject* UMLUseCase::clone() const
+{
     UMLUseCase *clone = new UMLUseCase();
     UMLObject::copyInto(clone);
     return clone;
 }
 
-void UMLUseCase::saveToXMI(QDomDocument& qDoc, QDomElement& qElement) {
+/**
+ * Creates the <UML:UseCase> element.
+ */
+void UMLUseCase::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
+{
     QDomElement usecaseElement = UMLObject::save("UML:UseCase", qDoc);
     qElement.appendChild(usecaseElement);
 }
 
-bool UMLUseCase::load(QDomElement& ) {
+/**
+ * Loads the <UML:UseCase> element (TODO).
+ */
+bool UMLUseCase::load(QDomElement& )
+{
     return true;
 }
 
